"use client"

import { useState, useEffect } from "react"
import Quiz from "@/components/quiz"

// Données pour l'exercice de perception des risques
const perceptionQuestions = [
  {
    qid: "perception-1",
    question: "Quelle est la situation à risque dans cette image?",
    correct_answer: "a",
    explanation: "Le piéton s'apprête à traverser sans regarder, ce qui représente un danger immédiat.",
    image_url: "/placeholder.svg?height=400&width=600",
    suggestion: ["Le piéton qui s'apprête à traverser", "La voiture garée à droite", "Le feu de signalisation"],
  },
  {
    qid: "perception-2",
    question: "Quel est le principal danger présenté dans cette scène?",
    correct_answer: "b",
    explanation: "Le cycliste ne porte pas de casque, augmentant le risque de blessure grave en cas de chute.",
    image_url: "/placeholder.svg?height=400&width=600",
    suggestion: ["La présence d'une voiture rouge", "Le cycliste sans casque", "L'état de la route"],
  },
  {
    qid: "perception-3",
    question: "Qu'est-ce qui rend cette intersection potentiellement dangereuse?",
    correct_answer: "c",
    explanation:
      "Le manque de visibilité dû aux arbres et aux bâtiments peut cacher des piétons ou d'autres véhicules.",
    image_url: "/placeholder.svg?height=400&width=600",
    suggestion: ["La couleur des bâtiments", "La présence de piétons", "Le manque de visibilité"],
  },
  {
    qid: "perception-4",
    question: "Quel est le risque principal dans cette situation de conduite?",
    correct_answer: "a",
    explanation: "L'utilisation du téléphone au volant diminue l'attention et augmente le temps de réaction.",
    image_url: "/placeholder.svg?height=400&width=600",
    suggestion: ["L'utilisation du téléphone", "La vitesse du véhicule", "La présence d'autres voitures"],
  },
  {
    qid: "perception-5",
    question: "Pourquoi cette zone de chantier est-elle particulièrement dangereuse?",
    correct_answer: "b",
    explanation: "La présence d'ouvriers et d'engins de chantier augmente le risque d'accident.",
    image_url: "/placeholder.svg?height=400&width=600",
    suggestion: ["La couleur des cônes", "La présence d'ouvriers et d'engins", "La signalisation temporaire"],
  },
]

export default function PerceptionExercisePage() {
  const [loading, setLoading] = useState(true)

  useEffect(() => {
    // Simuler un chargement
    const timer = setTimeout(() => {
      setLoading(false)
    }, 500)

    return () => clearTimeout(timer)
  }, [])

  if (loading) {
    return (
      <div className="min-h-screen flex justify-center items-center bg-gray-50">
        <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-blue-500"></div>
      </div>
    )
  }

  return (
    <div className="min-h-screen bg-gray-50">
      <Quiz title="Exercice: Perception des risques" questions={perceptionQuestions} type="exercise" />
    </div>
  )
}
